==> fediz-spring-1.3.3-sources.jar: org/apache/cxf/fediz/spring/authentication/FederationResponseAuthenticationToken.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.fediz.spring.authentication;

import java.util.ArrayList;

import org.apache.cxf.fediz.core.processor.FedizResponse;
import org.springframework.security.authentication.AbstractAuthenticationToken;
import org.springframework.security.core.GrantedAuthority;
import org.springframework.security.core.SpringSecurityCoreVersion;

public final class FederationResponseAuthenticationToken extends AbstractAuthenticationToken {

    private static final long serialVersionUID = SpringSecurityCoreVersion.SERIAL_VERSION_UID;

    private final FedizResponse response;


    public FederationResponseAuthenticationToken(final FedizResponse response) {
        super(new ArrayList<GrantedAuthority>());

        this.response = response;
    }

    public Object getPrincipal() {
        return this.response.getUsername();
    }

    public Object getCredentials() {
        return this.response;
    }
    
    public FedizResponse getResponse() {
        return this.response;
    }

}

==> fediz-spring2-1.3.0-sources.jar: org/apache/cxf/fediz/spring/authentication/FederationResponseAuthenticationToken.java <==
/**
 * Licensed to the Apache Software Foundation (ASF) under one
 * or more contributor license agreements. See the NOTICE file
 * distributed with this work for additional information
 * regarding copyright ownership. The ASF licenses this file
 * to you under the Apache License, Version 2.0 (the
 * "License"); you may not use this file except in compliance
 * with the License. You may obtain a copy of the License at
 *
 * http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing,
 * software distributed under the License is distributed on an
 * "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY
 * KIND, either express or implied. See the License for the
 * specific language governing permissions and limitations
 * under the License.
 */

package org.apache.cxf.fediz.spring.authentication;

import org.apache.cxf.fediz.core.processor.FedizResponse;
import org.springframework.security.providers.AbstractAuthenticationToken;

public final class FederationResponseAuthenticationToken extends AbstractAuthenticationToken {

    private static final long serialVersionUID = 1L;

    private final FedizResponse response;


    public FederationResponseAuthenticationToken(final FedizResponse response) {
        super(null);

        this.response = response;
    }

    public Object getPrincipal() {
        return this.response.getUsername();
    }

    public Object getCredentials() {
        return this.response;
    }
    
    public FedizResponse getResponse() {
        return this.response;
    }

}
